{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "'tenpo' 'ilo' #h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBh => "E h B",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Eh => "E h\N{U+202f}a",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyM => "G y-MM",
    GyMEd => "G y-MM-dd, E",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "G y-MM-dd",
    H => "HH",
    Hm => "#HH:mm",
    Hms => "#HH:mm:ss",
    Hmsv => "#HH:mm:ss 'lon' v",
    Hmv => "HH:mm v",
    Hv => "HH v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "MMMM 'la' 'sike' 'esun' #W",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "#d",
    h => "'tenpo' 'ilo' #h\N{U+202f}a",
    hm => "#h:mm\N{U+202f}a",
    hms => "#h:mm:ss\N{U+202f}a",
    hmsv => "#h:mm:ss\N{U+202f}a 'lon' v",
    hmv => "#h:mm\N{U+202f}a 'lon' v",
    hv => "h\N{U+202f}a v",
    ms => "mm:ss",
    y => "#y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "#y 'la' MMMM",
    yMMMd => "'sike' #y ) #M ) #d",
    yMd => "#y)#M)#d",
    yQQQ => "#y 'la' QQQ",
    yQQQQ => "#y 'la' QQQQ",
    "yw-count-other" => "Y 'la' 'sike' 'esun' #w",
  },
  code => "tok-001",
  date_format_full => "'sike' #y 'la' MMM 'la' 'suno' #d",
  date_format_long => "'tenpo' 'sike' #y 'la' 'tenpo' MMMM 'la' 'tenpo' 'suno' #d",
  date_format_medium => "'sike' #y 'la' MMM 'la' 'suno' #d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "suno esun #1",
    "suno esun #2",
    "suno esun #3",
    "suno esun #4",
    "suno esun #5",
    "suno esun #6",
    "suno esun #7",
  ],
  day_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
  ],
  day_format_wide => [
    "suno esun #1",
    "suno esun #2",
    "suno esun #3",
    "suno esun #4",
    "suno esun #5",
    "suno esun #6",
    "suno esun #7",
  ],
  day_stand_alone_abbreviated => [
    "suno esun #1",
    "suno esun #2",
    "suno esun #3",
    "suno esun #4",
    "suno esun #5",
    "suno esun #6",
    "suno esun #7",
  ],
  day_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
  ],
  day_stand_alone_wide => [
    "suno esun #1",
    "suno esun #2",
    "suno esun #3",
    "suno esun #4",
    "suno esun #5",
    "suno esun #6",
    "suno esun #7",
  ],
  era_abbreviated => [
    "BCE",
    "CE",
  ],
  era_narrow => [
    "BCE",
    "CE",
  ],
  era_wide => [
    "BCE",
    "CE",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Toki Pona",
  month_format_abbreviated => [
    "tenpo mun #1",
    "tenpo mun #2",
    "tenpo mun #3",
    "tenpo mun #4",
    "tenpo mun #5",
    "tenpo mun #6",
    "tenpo mun #7",
    "tenpo mun #8",
    "tenpo mun #9",
    "tenpo mun #10",
    "tenpo mun #11",
    "tenpo mun #12",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "tenpo mun #1",
    "tenpo mun #2",
    "tenpo mun #3",
    "tenpo mun #4",
    "tenpo mun #5",
    "tenpo mun #6",
    "tenpo mun #7",
    "tenpo mun #8",
    "tenpo mun #9",
    "tenpo mun #10",
    "tenpo mun #11",
    "tenpo mun #12",
  ],
  month_stand_alone_abbreviated => [
    "tenpo mun #1",
    "tenpo mun #2",
    "tenpo mun #3",
    "tenpo mun #4",
    "tenpo mun #5",
    "tenpo mun #6",
    "tenpo mun #7",
    "tenpo mun #8",
    "tenpo mun #9",
    "tenpo mun #10",
    "tenpo mun #11",
    "tenpo mun #12",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "tenpo mun #1",
    "tenpo mun #2",
    "tenpo mun #3",
    "tenpo mun #4",
    "tenpo mun #5",
    "tenpo mun #6",
    "tenpo mun #7",
    "tenpo mun #8",
    "tenpo mun #9",
    "tenpo mun #10",
    "tenpo mun #11",
    "tenpo mun #12",
  ],
  name => "Toki Pona world",
  native_language => "toki pona",
  native_name => "toki pona ma ale",
  native_script => undef,
  native_territory => "ma ale",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => "world",
  time_format_full => "zzzz 'la' HH:mm:ss",
  time_format_long => "z 'la' HH:mm:ss",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 48,
}
